@@ -6,7 +6,7 @@ oslo.dm <- list(dd=obs0$day,mm=obs0$month,yy=obs0$year,
             obs.name=c("Daily mean temperature","Daily precipitation"),
             unit=c("deg C","mm/day"),station=obs0$station.number[1],
             lat=59.95,lon=10.72,alt=94,ele=c("tam","rr"),
-            x.0E65N=NULL,y.0E65N=NULL,found=T,
+            x.0E65N=NULL,y.0E65N=NULL,found=TRUE,
             location="Oslo-Blindern",wmo.no=NULL,
             start=1937,yy0=1980, country="Norway",ref="www.met.no")
 class(oslo.dm) <- c("station","daily.station.record")
